..
    :copyright: Copyright (c) 2015 ftrack

.. _api_reference/resource_identifier_transformer.base:

***********************************************
ftrack_api.resource_identifier_transformer.base
***********************************************

.. automodule:: ftrack_api.resource_identifier_transformer.base
